@@ -3,7 +3,8 @@
 var google, django, gettext;
 
 (function () {
-    var jQuery = jQuery || $ || django.jQuery;
+    var jQuery = window.jQuery || $ || django.jQuery;
+
     /* Add a new selector to jQuery that excludes parent items which match a given selector */
     jQuery.expr[':'].parents = function(a, i, m) {
         return jQuery(a).parents(m[3]).length < 1;
@@ -186,7 +187,10 @@ var google, django, gettext;
             // TODO: Refactor
             $('.mt').parents('.inline-group').not('.tabular').find('.add-row a').click(function () {
                 var grouper = new TranslationFieldGrouper({
-                    $fields: $(this).parent().prev().prev().find('.mt')
+                    $fields: $(this).parent().prev().prev().find('.mt').add(
+                        // Support django-nested-admin stacked inlines
+                        $(this).parent().prev('.djn-items').children('.djn-item').last().find('.mt')
+                    )
                 });
                 var tabs = createTabs(grouper.groupedTranslations);
                 // Update the main switch as it is not aware of the newly created tabs
@@ -212,7 +216,7 @@ var google, django, gettext;
             this.getAllGroupedTranslations = function () {
                 var grouper = new TranslationFieldGrouper({
                     $fields: this.$table.find('.mt').filter(
-                        'input:visible, textarea:visible, select:visible')
+                        'input, textarea, select')
                 });
                 //this.requiredColumns = this.getRequiredColumns();
                 this.initTable();
@@ -391,7 +395,7 @@ var google, django, gettext;
             // Group normal fields and fields in (existing) stacked inlines
             var grouper = new TranslationFieldGrouper({
                 $fields: $('.mt').filter(
-                    'input:visible, textarea:visible, select:visible').filter(':parents(.tabular)')
+                    'input:visible, textarea:visible, select:visible, iframe, div').filter(':parents(.tabular)')
             });
             MainSwitch.init(grouper.groupedTranslations, createTabs(grouper.groupedTranslations));
 
