@@ -2,6 +2,7 @@
 """
 Settings overrided for test time
 """
+import django
 from django.conf import settings
 
 
@@ -22,3 +23,9 @@ MODELTRANSLATION_AUTO_POPULATE = False
 MODELTRANSLATION_FALLBACK_LANGUAGES = ()
 
 ROOT_URLCONF = 'modeltranslation.tests.urls'
+
+if django.VERSION < (1, 11):
+    # TODO: Check what this was about
+    MIGRATION_MODULES = {'auth': 'modeltranslation.tests.auth_migrations'}
+else:
+    MIGRATION_MODULES = {}
